<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Controller\Request;

use Magento\Framework\App\Action\Context;

/**
 * Class Fields
 */
class Fields extends \Magento\Framework\App\Action\Action
{
    /**
     * @var \Lhv\HirePurchase\Model\Request\BuilderCompositeFactory
     */
    protected $builderCompositeFactory;

    /**
     * @var \Magento\Sales\Api\OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Magento\Checkout\Model\Session
     */
    protected $checkoutSession;

    /**
     * @var \Lhv\HirePurchase\Logger\Logger
     */
    protected $logger;

    /**
     * @param Context $context
     * @param \Lhv\HirePurchase\Model\Request\BuilderCompositeFactory $builderCompositeFactory
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param \Magento\Checkout\Model\Session $checkoutSession
     * @param \Lhv\HirePurchase\Logger\Logger $logger
     */
    public function __construct(
        Context $context,
        \Lhv\HirePurchase\Model\Request\BuilderCompositeFactory $builderCompositeFactory,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Checkout\Model\Session $checkoutSession,
        \Lhv\HirePurchase\Logger\Logger $logger
    ) {
        parent::__construct($context);
        $this->builderCompositeFactory = $builderCompositeFactory;
        $this->orderRepository = $orderRepository;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->checkoutSession = $checkoutSession;
        $this->logger = $logger;
    }

    /**
     * Get the request fields
     *
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
        $result = $this->resultJsonFactory->create();

        $orderId = $this->checkoutSession->getLastOrderId();
        $requestBuilder = $this->builderCompositeFactory->create();

        $order = null;

        try {
            $order = $this->orderRepository->get($orderId);
        } catch (\Magento\Framework\Exception\NoSuchEntityException $e) {
            $this->logger->error('Exception when constructing post data', [$e->getMessage()]);
            return $result->setData(['error' => __($e->getMessage())]);
        }

        $requestData = [];

        if ($order && $order->getPayment()->getMethod() == \Lhv\HirePurchase\Model\ConfigProvider::LHV_HP_CODE &&
            $order->getQuoteId() == $this->checkoutSession->getQuoteId()) {
            try {
                $requestData = $requestBuilder->build($order);
            } catch (\Exception $e) {
                $this->logger->error('Exception when constructing post data', [$e->getMessage()]);
                return $result->setData(['error' => __('An error occurred on the server. Please select another payment method or contact us.')]);
            }
        }

        $this->logger->info('request', [$requestData]);
        return $result->setData($requestData);
    }
}