<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Controller\Response;

use Magento\Framework\App\Action\Context;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\ResultFactory;

/**
 * Class Index
 */
class Index extends \Magento\Framework\App\Action\Action
{
    /**
     * @var \Lhv\HirePurchase\Model\Response\Handler
     */
    protected $responseHandler;

    /**
     * @var \Lhv\HirePurchase\Logger\Logger
     */
    protected $logger;

    /**
     * @var \Magento\Framework\Stdlib\DateTime\Timezone
     */
    protected $timezone;

    /**
     * @param Context $context
     * @param \Lhv\HirePurchase\Model\Response\Handler $responseHandler
     * @param \Lhv\HirePurchase\Logger\Logger $logger
     */
    public function __construct(
        Context $context,
        \Lhv\HirePurchase\Model\Response\Handler $responseHandler,
        \Lhv\HirePurchase\Logger\Logger $logger,
        \Magento\Framework\Stdlib\DateTime\Timezone $timezone
    ) {
        parent::__construct($context);
        $this->responseHandler = $responseHandler;
        $this->logger = $logger;
        $this->timezone = $timezone;
    }

    /**
     * Dispatch request
     *
     * @return \Magento\Framework\Controller\ResultInterface|ResponseInterface
     * @throws \Magento\Framework\Exception\NotFoundException
     */
    public function execute()
    {
        $params = $this->getRequest()->getParams();

        $handlingResult = false;

        $time = $this->timezone->date()->format('d-m-Y H:i:s');
        $this->logger->info("Received response at " . $time, [$params]);

        try {
            $handlingResult = $this->responseHandler->handle($params);
        } catch (\Exception $e) {
            $this->logger->error('Exception when handling response', [$params, $e->getMessage()]);
            $this->messageManager->addErrorMessage(__('An error occurred on the server. Please select another payment method or contact us.'));
        }

        if ($handlingResult === true) {
            return $this->_redirect('checkout/onepage/success');
        } else {
            $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
            return $resultRedirect->setPath('checkout/cart');
        }
    }
}