<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Gateway\Config;

use \Lhv\HirePurchase\Model\Adminhtml\Source\Environment;

/**
 * Class Config
 */
class Config extends \Magento\Payment\Gateway\Config\Config
{
    const KEY_ACTIVE = 'active';
    const KEY_MIN_ORDER_TOTAL = 'min_order_total';
    const KEY_MAX_ORDER_TOTAL = 'max_order_total';
    const KEY_TITLE = 'title';
    const KEY_DISPLAY_LOGO = 'display_logo';
    const KEY_SORT_ORDER = 'sort_order';
    const KEY_ENVIRONMENT = 'environment';
    const KEY_MERCHANT_ID = 'merchant_id';
    const KEY_PRIVATE_KEY = 'private_key';
    const KEY_PRIVATE_KEY_PASSWORD = 'private_key_password';
    const KEY_PUBLIC_KEY = 'public_key';
    const KEY_PRODUCTION_ENDPOINT_URL = 'production_endpoint_url';
    const KEY_TEST_ENDPOINT_URL = 'test_endpoint_url';
    const KEY_SUPPORTED_LANGUAGES = 'supported_languages';

    /**
     * Get the configuration status
     *
     * @return bool
     */
    public function isActive()
    {
        return (bool)$this->getValue(self::KEY_ACTIVE);
    }

    /**
     * Get the minimum order total to allow method in checkout
     *
     * @return string
     */
    public function getMinOrderTotal()
    {
        return $this->getValue(self::KEY_MIN_ORDER_TOTAL);
    }

    /**
     * Get the maximum order total to allow method in checkout
     *
     * @return string
     */
    public function getMaxOrderTotal()
    {
        return $this->getValue(self::KEY_MAX_ORDER_TOTAL);
    }

    /**
     * Get the title of the payment method
     *
     * @return string
     */
    public function getTitle()
    {
        return $this->getValue(self::KEY_TITLE);
    }

    /**
     * Display logo on front end
     *
     * @return bool
     */
    public function getDisplayLogo()
    {
        return $this->getValue(self::KEY_DISPLAY_LOGO) == 1;
    }

    /**
     * Get the sort order in checkout
     *
     * @return int
     */
    public function getSortOrder()
    {
        return (int)$this->getValue(self::KEY_SORT_ORDER);
    }

    /**
     * Get the environment
     *
     * @return string
     */
    public function getEnvironment()
    {
        return $this->getValue(self::KEY_ENVIRONMENT);
    }

    /**
     * Get the merchant id
     *
     * @return string
     */
    public function getMerchantId()
    {
        return $this->getValue(self::KEY_MERCHANT_ID);
    }

    /**
     * Get the private key
     *
     * @return string
     */
    public function getPrivateKey()
    {
        return $this->getValue(self::KEY_PRIVATE_KEY);
    }

    /**
     * Get the private key password
     *
     * @return string
     */
    public function getPrivateKeyPassword()
    {
        return $this->getValue(self::KEY_PRIVATE_KEY_PASSWORD);
    }

    /**
     * Get the public key
     *
     * @return string
     */
    public function getPublicKey()
    {
        return $this->getValue(self::KEY_PUBLIC_KEY);
    }

    /**
     * Get the production environment endpoint url
     *
     * @return string
     */
    public function getProductionEndpointUrl()
    {
        return $this->getValue(self::KEY_PRODUCTION_ENDPOINT_URL);
    }

    /**
     * Get the test environment endpoint url
     *
     * @return string
     */
    public function getTestEndpointUrl()
    {
        return $this->getValue(self::KEY_TEST_ENDPOINT_URL);
    }

    /**
     * Get the currently configured environment endpoint url
     *
     * @return string|null
     */
    public function getEndpointUrl()
    {
        if ($this->getEnvironment() == Environment::ENVIRONMENT_PRODUCTION) {
            return $this->getProductionEndpointUrl();
        } else if ($this->getEnvironment() == Environment::ENVIRONMENT_TEST) {
            return $this->getTestEndpointUrl();
        }

        return null;
    }

    /**
     * Get the supported languages
     *
     * @return array
     */
    public function getSupportedLanguages()
    {
        $languages = $this->getValue(self::KEY_SUPPORTED_LANGUAGES);
        return explode(',', trim($languages));
    }

}