<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model;

use Lhv\HirePurchase\Gateway\Config\Config;
use Magento\Checkout\Model\ConfigProviderInterface;

/**
 * Class ConfigProvider
 */
class ConfigProvider implements ConfigProviderInterface
{
    /**
     * Payment method code
     */
    const LHV_HP_CODE = 'lhv_hp';

    /**
     * @var Config
     */
    protected $config;

    /**
     * @var \Magento\Framework\View\Asset\Repository
     */
    protected $assetRepository;

    /**
     * @var \Magento\Framework\App\ProductMetadataInterface
     */
    protected $productMetadata;

    /**
     * @var \Magento\Framework\UrlInterface
     */
    protected $urlInterface;

    /**
     * @param Config $config
     * @param \Magento\Framework\View\Asset\Repository $assetRepository
     * @param \Magento\Framework\UrlInterface $urlInterface
     */
    public function __construct(
        Config $config,
        \Magento\Framework\View\Asset\Repository $assetRepository,
        \Magento\Framework\UrlInterface $urlInterface,
        \Lhv\HirePurchase\Block\Description $descriptionBlock
    ) {
        $this->config = $config;
        $this->assetRepository = $assetRepository;
        $this->urlInterface = $urlInterface;
        $this->descriptionBlock = $descriptionBlock;
    }

    /**
     * Retrieve assoc array of checkout configuration
     *
     * @return array
     */
    public function getConfig()
    {
        return [
            'payment' => [
                'lhv_hp' => [
                    'post_action' => $this->config->getEndpointUrl(),
                    'fields_action' => $this->urlInterface->getUrl('lhvhp/request/fields'),
                    'code' => self::LHV_HP_CODE,
                    'logo' => $this->assetRepository->getUrl('Lhv_HirePurchase::images/jarelmaks_badge_EE.PNG'),
                    'display_logo' => $this->config->getDisplayLogo(),
                    'description' => $this->getDescription(),
                ]
            ]
        ];
    }

    /**
     * Get description as html
     *
     * @return string
     */
    protected function getDescription()
    {
        return $this->descriptionBlock->toHtml();
    }
}