<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Request;

/**
 * Class ApiDataBuilder
 */
class ApiDataBuilder extends Builder
{
    /**
     * Service number
     */
    const FIELD_VK_SERVICE = 'VK_SERVICE';

    /**
     * Request issuer (merchant) ID
     */
    const FIELD_VK_SND_ID = 'VK_SND_ID';

    /**
     * Request receiver ID
     */
    const FIELD_VK_REC_ID = 'VK_REC_ID';

    /**
     * Url, where the 5111, 5112 or 5113 response will be sent and where the user's browser will be redirected
     */
    const FIELD_VK_RESPONSE = 'VK_RESPONSE';

    /**
     * Url, where the user will be redirected when clicked on "Back to merchant" link
     */
    const FIELD_VK_RETURN = 'VK_RETURN';

    /**
     * Request encoding
     */
    const FIELD_VK_ENCODING = 'VK_ENCODING';

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var \Lhv\HirePurchase\Gateway\Config\Config
     */
    protected $config;

    /**
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Lhv\HirePurchase\Gateway\Config\Config $config
     */
    public function __construct(
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Lhv\HirePurchase\Gateway\Config\Config $config
    ) {
        $this->storeManager = $storeManager;
        $this->config = $config;
    }

    /**
     * {@inheritdoc}
     */
    public function build($order)
    {
        return [
            self::FIELD_VK_SERVICE => $this->createFieldEntry(1, '5011'),
            self::FIELD_VK_SND_ID => $this->createFieldEntry(3, $this->config->getMerchantId()),
            self::FIELD_VK_REC_ID => $this->createFieldEntry(4, 'LHV'),
            self::FIELD_VK_RESPONSE => $this->createFieldEntry(7, $this->getResponseUrl()),
            self::FIELD_VK_RETURN => $this->createFieldEntry(8, $this->getReturnUrl()),
            self::FIELD_VK_ENCODING => $this->createFieldEntry(self::ORDER_NOT_REQUIRED + 1, 'UTF-8')
        ];
    }

    /**
     * Get the response action url
     *
     * @return string
     */
    protected function getResponseUrl()
    {
        return sprintf("%s%s", $this->getStoreBaseUrl(), 'lhvhp/response/index');
    }

    /**
     * Get the return action url
     *
     * @return string
     */
    protected function getReturnUrl()
    {
        return sprintf("%s%s", $this->getStoreBaseUrl(), 'lhvhp/response/returnaction');
    }

    /**
     * Return the base url of the current store
     *
     * @return string
     */
    protected function getStoreBaseUrl()
    {
        return $this->storeManager->getStore()->getBaseUrl();
    }
}