<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Request;

use Magento\Framework\ObjectManager\TMapFactory;

/**
 * Class BuilderComposite
 */
class BuilderComposite extends Builder
{
    /**
     * @var \Magento\Framework\ObjectManager\TMap
     */
    protected $builders;

    /**
     * @param TMapFactory $tmapFactory
     * @param array $builders
     */
    public function __construct(
        TMapFactory $tmapFactory,
        array $builders = []
    ) {
        $this->builders = $tmapFactory->create(
            [
                'array' => $builders,
                'type' => \Lhv\HirePurchase\Model\Request\BuilderInterface::class
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function build($order)
    {
        $merged = $this->mergeOutputs($order);
        $sorted = $this->sortFields($merged);
        $result = $this->getFlatAssocArray($sorted);

        if ($this->builders->offsetExists('security')) {
            $result = $this->builders
                ->offsetGet('security')
                ->setMacField($result);
        }

        return $result;
    }

    /**
     * Collect the outputs from all builders and merge them into one array
     *
     * @param \Magento\Sales\Model\Order $order
     * @return array
     */
    protected function mergeOutputs($order)
    {
        $merged = [];

        foreach ($this->builders as $builder) {
            $merged = $this->merge($merged, $builder->build($order));
        }

        return $merged;
    }

    /**
     * Sort the fields by their sort order
     *
     * @param array $fields
     * @return array
     */
    protected function sortFields($fields)
    {
        uasort($fields, function ($item1, $item2) {
            if ($item1['sort_order'] == $item2['sort_order']) return 0;
            return $item1['sort_order'] < $item2['sort_order'] ? -1 : 1;
        });

        return $fields;
    }

    /**
     * Convert assoc array of assoc arrays to a simple assoc array
     *
     * @param array $fields
     * @return array
     */
    protected function getFlatAssocArray($fields)
    {
        $result = [];
        foreach ($fields as $key => $value) {
            $result[$key] = $value['value'];
        }

        return $result;
    }

    /**
     * Merge function for builders
     *
     * @param array $result
     * @param array $builder
     * @return array
     */
    protected function merge(array $result, array $builder)
    {
        return array_replace_recursive($result, $builder);
    }
}