<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Request;

/**
 * Class CustomerDataBuilder
 */
class CustomerDataBuilder extends Builder
{
    /**
     * Preferred interface language
     */
    const FIELD_VK_LANG = 'VK_LANG';

    /**
     * Customer's e-mail
     */
    const FIELD_VK_EMAIL = 'VK_EMAIL';

    /**
     * Customer's phone number
     */
    const FIELD_VK_PHONE = 'VK_PHONE';

    /**
     * @var \Magento\Framework\Locale\Resolver
     */
    protected $localeResolver;

    /**
     * @param \Magento\Framework\Locale\Resolver $localeResolver
     */
    public function __construct(
        \Magento\Framework\Locale\Resolver $localeResolver
    ) {
        $this->localeResolver = $localeResolver;
    }

    /**
     * {@inheritdoc}
     */
    public function build($order)
    {
        $data = [];

        $languageCode = $this->getLanguageCode();
        if ($languageCode) {
            $data[self::FIELD_VK_LANG ] = $this->createFieldEntry(
                self::ORDER_NOT_REQUIRED + 2,
                $languageCode
            );
        }

        if ($order->getCustomerEmail()) {
            $data[self::FIELD_VK_EMAIL ] = $this->createFieldEntry(
                self::ORDER_NOT_REQUIRED + 3,
                $order->getCustomerEmail()
            );
        }

        if ($order->getBillingAddress() && $order->getBillingAddress()->getTelephone()) {
            $data[self::FIELD_VK_PHONE ] = $this->createFieldEntry(
                self::ORDER_NOT_REQUIRED + 4,
                $order->getBillingAddress()->getTelephone()
            );
        }

        return $data;
    }

    /**
     * Return the language if the current locale is supported, otherwise return null
     *
     * @return string|null
     */
    protected function getLanguageCode()
    {
        $supportedLocales = ['et_EE' => 'EST', 'ru_RU' => 'RUS'];
        $locale = $this->localeResolver->getLocale();

        foreach ($supportedLocales as $supportedLocale => $languageCode) {
            if ($locale == $supportedLocale) {
                return $languageCode;
            }
        }

        return null;
    }

}