<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Request;

/**
 * Class OrderDataBuilder
 */
class OrderDataBuilder extends Builder
{
    /**
     * Request's additional data in XML
     */
    const FIELD_VK_DATA = 'VK_DATA';

    /**
     * Request issuer generated stamp
     *
     * In this case we are using the order id, so we can easily access the order later in the response
     */
    const FIELD_VK_STAMP = 'VK_STAMP';

    /**
     * @var \Magento\Framework\Stdlib\DateTime\Timezone
     */
    protected $timezone;

    /**
     * @param \Magento\Framework\Stdlib\DateTime\Timezone $timezone
     */
    public function __construct(
        \Magento\Framework\Stdlib\DateTime\Timezone $timezone
    ) {
        $this->timezone = $timezone;
    }

    /**
     * {@inheritdoc}
     */
    public function build($order)
    {
        return [
            self::FIELD_VK_STAMP => $this->createFieldEntry(5, $order->getId()),
            self::FIELD_VK_DATA => $this->createFieldEntry(6, $this->getCofContractXml($order)),
        ];
    }

    /**
     * Get the xml for VK_DATA field
     *
     * @param \Magento\Sales\Model\Order $order
     * @return string
     */
    protected function getCofContractXml($order)
    {
        $costVatPercent = 0;

        foreach ($order->getItems() as $item) {
            if ($item->getTaxPercent() > $costVatPercent) {
                $costVatPercent = (float)$item->getTaxPercent();
            }
        }

        $xml = '<CofContractProductList>';
        $xml .= '<CofContractProduct>';
        $xml .= '<Name>Tellimus</Name>';
        $xml .= '<Code>' . $order->getIncrementId() . '</Code>';
        $xml .= '<Currency>' . 'EUR' . '</Currency>';
        $xml .= '<CostInclVatAmount>' . $order->getGrandTotal() . '</CostInclVatAmount>';
        $xml .= '<CostVatPercent>' . $costVatPercent . '</CostVatPercent>';
        $xml .= '</CofContractProduct>';
        $xml .= '<ValidToDtime>' . $this->getValidToDateTime() . '</ValidToDtime>';
        $xml .= '</CofContractProductList>';

        return $xml;
    }

    /**
     * Get a valid to date and time in ISO 8601 format with timezone
     *
     * @return false|string
     */
    protected function getValidToDateTime()
    {
        //randomly adds 2 hours to current time
        return $this->timezone->date()->add(new \DateInterval('PT2H'))->format('Y-m-d\TH:i:sP');
    }
}