<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Request;

/**
 * Class SecurityDataBuilder
 */
class SecurityDataBuilder extends Builder
{
    /**
     * Encryption algorithm used
     */
    const FIELD_VK_VERSION = 'VK_VERSION';

    /**
     * Request initiation date and time in ISO 8601 format with timezone (eg . 2015-02-05T07:18:11+02:00)
     */
    const FIELD_VK_DATETIME = 'VK_DATETIME';

    /**
     * Message authentication code
     */
    const FIELD_VK_MAC = 'VK_MAC';

    /**
     * @var \Magento\Framework\Stdlib\DateTime\Timezone
     */
    protected $timezone;

    /**
     * @var \Lhv\HirePurchase\Model\Security\MacCalculation
     */
    protected $macCalculation;

    /**
     * @param \Magento\Framework\Stdlib\DateTime\Timezone $timezone
     * @param \Lhv\HirePurchase\Model\Security\MacCalculation $macCalculation
     */
    public function __construct(
        \Magento\Framework\Stdlib\DateTime\Timezone $timezone,
        \Lhv\HirePurchase\Model\Security\MacCalculation $macCalculation
    ) {
        $this->timezone = $timezone;
        $this->macCalculation = $macCalculation;
    }

    /**
     * {@inheritdoc}
     */
    public function build($order)
    {
        return [
            self::FIELD_VK_VERSION => $this->createFieldEntry(2, '008'),
            self::FIELD_VK_DATETIME => $this->createFieldEntry( 9, $this->getDateTime()),
            self::FIELD_VK_MAC => $this->createFieldEntry(10, '')
        ];
    }

    /**
     * Set the mac field in a properly formatted request array
     *
     * @param array $fields
     * @return array
     */
    public function setMacField($fields)
    {
        $fields['VK_MAC'] = $this->macCalculation->calculateMac($fields);
        return $fields;
    }

    /**
     * Get a current date and time in ISO 8601 format with timezone
     *
     * @return false|string
     */
    protected function getDateTime()
    {
        return $this->timezone->date()->format('Y-m-d\TH:i:sO');
    }
}