<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Response;

/**
 * Class Handler
 */
class Handler
{
    /**
     * Successful service code
     */
    const SUCCESS = '5111';

    /**
     * Negative service code
     */
    const NEGATIVE = '5113';

    /**
     * @var \Magento\Framework\Message\ManagerInterface
     */
    protected $messageManager;

    /**
     * @var Validator
     */
    protected $validator;

    /**
     * @var Processor
     */
    protected $processor;

    /**
     * @param \Magento\Framework\Message\ManagerInterface $messageManager
     * @param \Lhv\HirePurchase\Model\Response\Validator $validator
     * @param \Lhv\HirePurchase\Model\Response\Processor $processor
     */
    public function __construct(
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Lhv\HirePurchase\Model\Response\Validator $validator,
        \Lhv\HirePurchase\Model\Response\Processor $processor
    ) {
        $this->validator = $validator;
        $this->messageManager = $messageManager;
        $this->processor = $processor;
    }

    /**
     * Handle the response
     *
     * Return true only if received successful service code
     *
     * @param array $response
     * @return bool
     */
    public function handle($response)
    {
        $validationResult = $this->validator->validate($response);

        if ($validationResult->getIsValid()) {
            return $this->handleValidResponse($response);
        }

        return $this->handleInvalidResponse($validationResult);
    }

    /**
     * Handle valid response data
     *
     * @param array $response
     * @return bool
     */
    protected function handleValidResponse($response)
    {
        $serviceCode = $response['VK_SERVICE'];

        if ($serviceCode == self::SUCCESS) {
            $this->processor->processOrder($response);
            $this->messageManager->addSuccessMessage(
                __('Your LHV hire-purchase contract was successfully signed and your order has been paid for.')
            );
        } else if ($serviceCode == self::NEGATIVE) {
            $this->processor->cancelOrderAndRestoreQuote();
            $this->messageManager->addErrorMessage(
                __('Since you are not eligible for LHV hire-purchase, please select another payment method.')
            );
        }

        return $serviceCode == self::SUCCESS;
    }

    /**
     * Handle invalid response data
     *
     * @param \Magento\Framework\DataObject $validationResult
     * @return bool
     */
    protected function handleInvalidResponse($validationResult)
    {
        foreach ($validationResult->getErrors() as $error) {
            $this->messageManager->addErrorMessage($error);
        }

        return false;
    }
}