<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Model\Response;

/**
 * Class Validator
 */
class Validator
{
    /**
     * @var \Lhv\HirePurchase\Gateway\Config\Config
     */
    protected $config;

    /**
     * @var \Lhv\HirePurchase\Model\Security\MacCalculation
     */
    protected $macCalculation;

    /**
     * @var \Magento\Framework\DataObject
     */
    protected $validationResult;

    /**
     * @var array
     */
    protected $response;

    /**
     * @var array
     */
    protected $errors;

    /**
     * @var array
     */
    protected $requiredFields = [
        'VK_SERVICE',
        'VK_VERSION',
        'VK_SND_ID',
        'VK_REC_ID',
        'VK_STAMP',
        'VK_DATA',
        'VK_DATETIME',
        'VK_MAC',
    ];

    /**
     * @param \Lhv\HirePurchase\Gateway\Config\Config $config
     * @param \Lhv\HirePurchase\Model\Security\MacCalculation $macCalculation
     */
    public function __construct(
        \Lhv\HirePurchase\Gateway\Config\Config $config,
        \Lhv\HirePurchase\Model\Security\MacCalculation $macCalculation
    ) {
        $this->config = $config;
        $this->macCalculation = $macCalculation;
        $this->validationResult = new \Magento\Framework\DataObject();
    }

    /**
     * Validates the response
     *
     * @param array $response
     * @return \Magento\Framework\DataObject
     */
    public function validate($response)
    {
        $this->response = $response;
        $this->errors = [];

        $this->areRequiredFieldsSet()
            ->verifyMac();

        $this->validationResult
            ->setErrors($this->errors)
            ->setIsValid(count($this->errors) == 0);

        return $this->getValidationResult();
    }

    /**
     * Get the validation result
     *
     * @return \Magento\Framework\DataObject
     */
    public function getValidationResult()
    {
        return $this->validationResult;
    }

    /**
     * Check whether the required response fields are set
     *
     * @return $this
     */
    protected function areRequiredFieldsSet()
    {
        foreach ($this->requiredFields as $field) {
            if (!isset($this->response[$field])) {
                $this->errors[] = __('Response field %1 is not set', $field);
            }
        }

        return $this;
    }

    /**
     * Check whether the MAC can be verified
     *
     * @return $this
     */
    protected function verifyMac()
    {
        if (!isset($this->response['VK_MAC']) || !$this->macCalculation->verifyMac($this->response)) {
            $this->errors[] = __('Response MAC is not verifiable');
        }

        return $this;
    }
}