<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Observer;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;

/**
 * Class IsAvailableValidator
 */
class IsAvailableValidator implements ObserverInterface
{
    /**
     * @var \Lhv\HirePurchase\Gateway\Config\Config
     */
    protected $config;

    /**
     * @param \Lhv\HirePurchase\Gateway\Config\Config $config
     */
    public function __construct(
        \Lhv\HirePurchase\Gateway\Config\Config $config
    ) {
        $this->config = $config;
    }

    /**
     * Make method not available if some additional validations fail
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $result = $observer->getEvent()->getResult();
        $methodInstance = $observer->getEvent()->getMethodInstance();

        if ($methodInstance->getCode() == \Lhv\HirePurchase\Model\ConfigProvider::LHV_HP_CODE) {
            $this->checkRequiredFields($result);
        }

        return $this;
    }

    /**
     * Check that required fields are set
     *
     * @param $result
     * @return void
     */
    protected function checkRequiredFields($result)
    {
        if (empty($this->config->getPrivateKey()) || empty($this->config->getPublicKey())
            || empty($this->config->getMerchantId())) {
            $result->setData('is_available', false);
        }
    }
}