<?php
/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
namespace Lhv\HirePurchase\Observer;

use Magento\Framework\Event\ObserverInterface;

/**
 * Class OrderEmailCancel
 */
class OrderEmailCancel implements ObserverInterface
{
    /**
     * Disallow sending the order email after placing the order
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $quote = $observer->getEvent()->getQuote();
        /** @var  \Magento\Sales\Model\Order $order */
        $order = $observer->getEvent()->getOrder();

        if ($this->hasLhvHPPaymentMethod($quote)) {
            $order->setCanSendNewEmailFlag(false);
        }

        return $this;
    }

    /**
     * Checks if quote that is being submitted has LHV-hp payment method
     *
     * @param \Magento\Quote\Model\Quote $quote
     * @return bool
     */
    protected function hasLhvHPPaymentMethod($quote)
    {
        return $quote->getPayment()->getMethodInstance()->getCode() == \Lhv\HirePurchase\Model\ConfigProvider::LHV_HP_CODE;
    }
}