/**
 * Copyright © Aedes Web Solutions. All rights reserved.
 */
define(
    [
        'jquery',
        'Magento_Checkout/js/view/payment/default',
        'Magento_Checkout/js/action/place-order',
        'Magento_Checkout/js/model/payment/additional-validators',
        'Lhv_HirePurchase/js/form-builder',
        'Magento_Ui/js/model/messageList',
        'mage/translate',
        'Magento_Checkout/js/model/full-screen-loader'
    ],
    function (
        $,
        Component,
        placeOrderAction,
        additionalValidators,
        formBuilder,
        globalMessageList,
        $t,
        fullScreenLoader
    ) {
        'use strict';
        return Component.extend({
            displayLogo: window.checkoutConfig.payment.lhv_hp.display_logo,
            redirectAfterPlaceOrder: false,
            defaults: {
                template: 'Lhv_HirePurchase/payment/lhv-hp'
            },
            getLogo: function() {
                return window.checkoutConfig.payment.lhv_hp.logo;
            },
            getCode: function() {
                return window.checkoutConfig.payment.lhv_hp.code;
            },
            getDescription: function() {
                return window.checkoutConfig.payment.lhv_hp.description;
            },
            showError: function (errorMessage) {
                globalMessageList.addErrorMessage({
                    message: errorMessage
                });
            },
            /**
             * Triggers when customer clicks the "Place Order" button
             */
            payWithLhvHP: function () {
                if (additionalValidators.validate()) {
                    this.placeOrder();
                }
            },
            afterPlaceOrder: function() {
                var self = this;

                $.ajax({
                    url: window.checkoutConfig.payment.lhv_hp.fields_action,
                    type: "GET"
                }).done(function (data) {
                    if (data) {
                        if (data.error) {
                            self.isPlaceOrderActionAllowed(true);
                            self.showError(data.error);
                            fullScreenLoader.stopLoader();
                            return false;
                        } else {
                            formBuilder.build(
                                {
                                    action: window.checkoutConfig.payment.lhv_hp.post_action,
                                    fields: data
                                }
                            ).submit();
                        }
                    }
                }).fail(function() {
                    self.isPlaceOrderActionAllowed(true);
                    self.showError($t('An error occurred on the server. Please select another payment method or contact us.'));
                    fullScreenLoader.stopLoader();
                    return false;
                });
            }
        });
    }
);